.. role:: xunit2rst-skip
    :class: xunit2rst skip
.. role:: xunit2rst-fail
    :class: xunit2rst fail
.. role:: xunit2rst-pass
    :class: xunit2rst pass

.. _qualification_test_report_qtest_nested_suites:

=================================================
Qualification Test Report for qtest_nested_suites
=================================================

The log file that contains details about the executed test cases can be found `here <testcases_base_log.html>`_.

.. contents:: `Contents`
    :depth: 2
    :local:


Test Reports
============

.. item:: REPORT_SWQTEST_TESTCASES_BASE-TEST_ANGLES_IN_ALL_QUADRANTS_IN_LEGACY_XY_MAGNETIC_MODE Test report for SWQTEST_TESTCASES_BASE-TEST_ANGLES_IN_ALL_QUADRANTS_IN_LEGACY_XY_MAGNETIC_MODE
    :passes: SWQTEST_TESTCASES_BASE-TEST_ANGLES_IN_ALL_QUADRANTS_IN_LEGACY_XY_MAGNETIC_MODE

    Test result: :xunit2rst-pass:`Pass`


.. item:: REPORT_SWQTEST_TESTCASES_BASE-TEST_RANDOM_ANGLES_IN_LEGACY_XY_MAGNETIC_MODE Test report for SWQTEST_TESTCASES_BASE-TEST_RANDOM_ANGLES_IN_LEGACY_XY_MAGNETIC_MODE
    :passes: SWQTEST_TESTCASES_BASE-TEST_RANDOM_ANGLES_IN_LEGACY_XY_MAGNETIC_MODE

    Test result: :xunit2rst-pass:`Pass`


.. item:: REPORT_SWQTEST_TESTCASES_BASE-TEST_ANGLES_IN_ALL_QUADRANTS_IN_LEGACY_XZ_MAGNETIC_MODE Test report for SWQTEST_TESTCASES_BASE-TEST_ANGLES_IN_ALL_QUADRANTS_IN_LEGACY_XZ_MAGNETIC_MODE
    :passes: SWQTEST_TESTCASES_BASE-TEST_ANGLES_IN_ALL_QUADRANTS_IN_LEGACY_XZ_MAGNETIC_MODE

    Test result: :xunit2rst-pass:`Pass`


.. item:: REPORT_SWQTEST_TESTCASES_BASE-TEST_RANDOM_ANGLES_IN_LEGACY_XZ_MAGNETIC_MODE Test report for SWQTEST_TESTCASES_BASE-TEST_RANDOM_ANGLES_IN_LEGACY_XZ_MAGNETIC_MODE
    :passes: SWQTEST_TESTCASES_BASE-TEST_RANDOM_ANGLES_IN_LEGACY_XZ_MAGNETIC_MODE

    Test result: :xunit2rst-pass:`Pass`


Traceability Matrix
===================

The below table traces the test report to test cases.

.. item-matrix:: Linking these qualification test reports to qualification test cases
    :source: REPORT_SWQTEST_TESTCASES_BASE-
    :target: SWQTEST_TESTCASES_BASE-
    :sourcetitle: Qualification test report
    :targettitle: Qualification test specification
    :type: fails passes skipped
    :stats:
    :group: top
    :nocaptions:
